==> magic-7.2.67.tar.bz2: magic-7.2.67/netmenu/netmenu.h <==
/*
 * netmenu.h --
 *
 * Defines the interface provided by the netmenu module.
 * This module implements a menu-based system for editing
 * labels and netlists.
 *
 *     ********************************************************************* 
 *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
 *     * Permission to use, copy, modify, and distribute this              * 
 *     * software and its documentation for any purpose and without        * 
 *     * fee is hereby granted, provided that the above copyright          * 
 *     * notice appear in all copies.  The University of California        * 
 *     * makes no representations about the suitability of this            * 
 *     * software for any purpose.  It is provided "as is" without         * 
 *     * express or implied warranty.  Export of this software outside     * 
 *     * of the United States of America may require an export license.    * 
 *     *********************************************************************
 *
 *
 * rcsid = "$Header: /ufs/repository/magic/netmenu/netmenu.h,v 1.1.1.1 2000/03/29 18:35:09 rajit Exp $";
 */

#define _NETMENU

/* data structures */

/* procedures */

extern void NMinit();
extern void NMUnsetCell();
extern Void NMNewNetlist();
extern Void NMWriteNetlist();
extern char *NMAddTerm();
extern Void NMDeleteTerm();
extern Void NMJoinNets();
extern Void NMDeleteNet();
extern int NMEnumNets();
extern int NMEnumTerms();
extern char *NMNthNet();
extern char *NMTermInList();
extern Void NMVerify();
extern bool NMHasList();
extern void NMFlushNetlist();
extern char *NMNetlistName();

#ifdef ROUTE_MODULE
extern void NMMeasureAll();
#endif

==> magic-7.3.11.tar.bz2: magic-7.3.11/netmenu/netmenu.h <==
/*
 * netmenu.h --
 *
 * Defines the interface provided by the netmenu module.
 * This module implements a menu-based system for editing
 * labels and netlists.
 *
 *     ********************************************************************* 
 *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
 *     * Permission to use, copy, modify, and distribute this              * 
 *     * software and its documentation for any purpose and without        * 
 *     * fee is hereby granted, provided that the above copyright          * 
 *     * notice appear in all copies.  The University of California        * 
 *     * makes no representations about the suitability of this            * 
 *     * software for any purpose.  It is provided "as is" without         * 
 *     * express or implied warranty.  Export of this software outside     * 
 *     * of the United States of America may require an export license.    * 
 *     *********************************************************************
 *
 *
 * rcsid = "$Header: /ufs/repository/magic/netmenu/netmenu.h,v 1.1.1.1 2000/03/29 18:35:09 rajit Exp $";
 */

#define _NETMENU

/* data structures */

/* procedures */

extern void NMinit();
extern void NMUnsetCell();
extern int NMNewNetlist();
extern int NMWriteNetlist();
extern char *NMAddTerm();
extern int NMDeleteTerm();
extern int NMJoinNets();
extern int NMDeleteNet();
extern int NMEnumNets();
extern int NMEnumTerms();
extern char *NMNthNet();
extern char *NMTermInList();
extern int NMVerify();
extern bool NMHasList();
extern void NMFlushNetlist();
extern char *NMNetlistName();

#ifdef ROUTE_MODULE
extern void NMMeasureAll();
#endif
